use sys::{
	ImPlotColormap__ImPlotColormap_Viridis, ImPlotHeatmapFlags,
	ImPlotHeatmapFlags__ImPlotHeatmapFlags_ColMajor,
};

use crate::sys;
use std::ffi::CString;
use std::os::raw::c_char;

pub use crate::sys::ImPlotPoint;

pub struct PlotHeatmap {
	label: CString,
}

impl PlotHeatmap {
	pub fn new(label: &str) -> Self {
		Self {
			label: CString::new(label)
				.unwrap_or_else(|_| panic!("label string has internal null bytes: {}", label)),
		}
	}

	pub fn plot(&self, x: &[f64], rows: i32, cols: i32) {
		if x.is_empty() {
			return;
		}

		unsafe {
			sys::ImPlot_PushColormap_PlotColormap(ImPlotColormap__ImPlotColormap_Viridis as i32);
			sys::ImPlot_PlotHeatmap_doublePtr(
				self.label.as_ptr() as *const c_char,
				x.as_ptr(),
				rows,
				cols,
				0.0,
				1.0,
				"%.0f\0".as_ptr() as *const c_char,
				ImPlotPoint {
					x: 0f64,
					y: rows as f64,
				},
				ImPlotPoint {
					x: cols as f64,
					y: 0f64,
				},
				ImPlotHeatmapFlags__ImPlotHeatmapFlags_ColMajor as ImPlotHeatmapFlags,
			);
		}
	}
}
