use sys::ImPlotInfLinesFlags__ImPlotInfLinesFlags_Horizontal;

use crate::sys;
use std::ffi::CString;
use std::os::raw::c_char;

pub use crate::sys::ImPlotPoint;

pub struct PlotLine {
	label: CString,
}

impl PlotLine {
	pub fn new(label: &str) -> Self {
		Self {
			label: CString::new(label)
				.unwrap_or_else(|_| panic!("label string has internal null bytes: {}", label)),
		}
	}

	pub fn plot_with_step(&self, x: &[f64], step: f64) {
		if x.is_empty() {
			return;
		}

		unsafe {
			sys::ImPlot_PlotLine_doublePtrInt(
				self.label.as_ptr() as *const c_char,
				x.as_ptr(),
				x.len() as i32,
				step,
				0f64,
				0,
				0,
				std::mem::size_of::<f64>() as i32,
			);
		}
	}

	pub fn plot_inf(&self, x: f64) {
		unsafe {
			sys::ImPlot_PlotInfLines_doublePtr(
				self.label.as_ptr() as *const c_char,
				&x,
				1,
				ImPlotInfLinesFlags__ImPlotInfLinesFlags_Horizontal as i32,
				0,
				8, /* sizeof(double) */
			);
		}
	}

	pub fn plot(&self, x: &[f64], y: &[f64]) {
		if x.len().min(y.len()) == 0 {
			return;
		}

		unsafe {
			sys::ImPlot_PlotLine_doublePtrdoublePtr(
				self.label.as_ptr() as *const c_char,
				x.as_ptr(),
				y.as_ptr(),
				x.len().min(y.len()) as i32,
				0,
				0,
				std::mem::size_of::<f64>() as i32,
			);
		}
	}
}
